@@ -7,6 +7,8 @@ use Zucchini::Version; our $VERSION = $Zucchini::VERSION;
 
 use Carp;
 use Config::Any;
+use Path::Class;
+use Zucchini::Config::Create;
 
 # no set method - we don't want any outside inteference
 my %data_of         :ATTR( get => 'data'                            );
@@ -18,6 +20,21 @@ use Class::Std;
     sub START {
         my ($self, $obj_ID, $arg_ref) = @_;
 
+        # if we've been asked to create a new config-file, do just that
+        # and exit
+        if ($arg_ref->{'create-config'}) {
+            my $zucchini_cfg_create = Zucchini::Config::Create->new();
+
+            $zucchini_cfg_create->write_default_config(
+                file($ENV{HOME}, q{.zucchini})
+            );
+
+            exit;
+        }
+
+        # store the config/arg_ref for future reference
+        $options_of{$obj_ID} = $arg_ref;
+
         # we'll allow (clever) people to pass a hashref for the config
         # (mostly useful for testing, but great for abuse too :) )
         if (ref($arg_ref->{config_data})) {
@@ -28,8 +45,14 @@ use Class::Std;
             $self->_load_config($obj_ID);
         }
 
-        # store the config/arg_ref for future reference
-        $options_of{$obj_ID} = $arg_ref;
+        # if we don't have a config file - abort
+        if (not defined $self->get_data) {
+            warn (
+                  file($ENV{HOME}, q{.zucchini})
+                . qq{: configuration file not found, use 'create-config' option to create one\n}
+            );
+            exit;
+        }
 
         # deal with user options
         if ($arg_ref->{site}) {
@@ -145,12 +168,13 @@ use Class::Std;
         my $self    = shift;
         my $obj_ID  = shift;
 
-        my $config_file = $ENV{HOME} . q{/.zucchini};
+        my $config_file = file($ENV{HOME}, q{/.zucchini});
 
         # read/load/parse the config file
         my $cfg = Config::Any->load_files(
             {
-                files => [ $config_file ],
+                files   => [ $config_file ],
+                use_ext => 0,
             }
         );
 
@@ -162,8 +186,9 @@ use Class::Std;
         }
 
         if (not defined $self->get_data()) {
-            warn "$config_file: no configuration data";
-            return undef;
+            warn "$config_file: no configuration data loaded\n"
+                if ($self->verbose);
+            return;
         }
 
         return;
